Class: Google::Cloud::Tasks::V2beta2::AttemptStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/tasks/v2beta2/task.rb

Overview

The status of a task attempt.

Instance Attribute Summary collapse

Instance Attribute Details

#dispatch_time::Google::Protobuf::Timestamp

Returns Output only. The time that this attempt was dispatched.

dispatch_time will be truncated to the nearest microsecond.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The time that this attempt was dispatched.

    dispatch_time will be truncated to the nearest microsecond.



201
202
203
204
# File 'proto_docs/google/cloud/tasks/v2beta2/task.rb', line 201

class AttemptStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#response_status::Google::Rpc::Status

Returns Output only. The response from the target for this attempt.

If the task has not been attempted or the task is currently running then the response status is unset.

Returns:

  • (::Google::Rpc::Status)

    Output only. The response from the target for this attempt.

    If the task has not been attempted or the task is currently running then the response status is unset.



201
202
203
204
# File 'proto_docs/google/cloud/tasks/v2beta2/task.rb', line 201

class AttemptStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#response_time::Google::Protobuf::Timestamp

Returns Output only. The time that this attempt response was received.

response_time will be truncated to the nearest microsecond.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The time that this attempt response was received.

    response_time will be truncated to the nearest microsecond.



201
202
203
204
# File 'proto_docs/google/cloud/tasks/v2beta2/task.rb', line 201

class AttemptStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#schedule_time::Google::Protobuf::Timestamp

Returns Output only. The time that this attempt was scheduled.

schedule_time will be truncated to the nearest microsecond.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The time that this attempt was scheduled.

    schedule_time will be truncated to the nearest microsecond.



201
202
203
204
# File 'proto_docs/google/cloud/tasks/v2beta2/task.rb', line 201

class AttemptStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end